package store-pushqueue

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Store_PushQueueSource

A push-only stack, with arbitrary element access.

Sourcetype 'a t
Sourceval create : Store.t -> 'a t
Sourceval length : Store.t -> 'a t -> int
Sourceval push : Store.t -> 'a t -> 'a -> unit
Sourceval get : Store.t -> 'a t -> int -> 'a

get store queue i gets the i-th element of the queue, indexed from the oldest, at index 0, to the most recent, at index length queue - 1.

  • raises Not_found

    if the index is not in range.